@@ -1,5 +1,5 @@
-from .generate import Generation
-from .detection_parse import DetectionParse
+from tunas2dsdl.generator.generate import Generation
+from tunas2dsdl.parser import DetectionParse
 from .general.classdomain import ClassDomain, Label
 from .general.struct import Struct, Field
 
