@@ -1,9 +1,9 @@
 import json
-import re
 from ..general import ClassDomain, Label
 from ..general import Field, Struct
 from ..general import DataSample
 from tqdm import tqdm
+from ..io import PetrelBackend, AliyunOSSBackend, HardDiskBackend, FileIO
 
 
 class DetectionParse:
@@ -11,7 +11,18 @@ class DetectionParse:
     DETECTION_ANN_TYPE = "box2d"
     PARENT_PATTERN = "Parent"
 
-    def __init__(self, data_info_file, ann_file, dataset_name=None):
+    def __init__(self, data_info_file, ann_file, separate_flag, dataset_name=None, config=None):
+        if FileIO.is_ceph_path(data_info_file):
+            self.file_client = PetrelBackend()
+        elif FileIO.is_oss_path(data_info_file):
+            assert config, "you must provide the configuration of aliyun oss."
+            bucket_name = FileIO.get_bucket_name(data_info_file)
+            data_info_file = FileIO.get_oss_rel_path(data_info_file)
+            ann_file = FileIO.get_oss_rel_path(ann_file)
+            self.file_client = AliyunOSSBackend(bucket_name=bucket_name, **config)
+        else:  # read from local
+            self.file_client = HardDiskBackend()
+        self.separate_flag = separate_flag
         self._dataset_name = dataset_name
         self._data_info_file = data_info_file
         self._annotation_file = ann_file
@@ -38,8 +49,8 @@ class DetectionParse:
         提取class domain相关的信息
         :return: 父类class domain对象，子类class domain对象，class原始信息字典
         """
-        class_domain = ClassDomain(self.clean(f"{self._dataset_name}ClassDom"))
-        parent_class_domain = ClassDomain(self.clean(f"{self._dataset_name}{self.PARENT_PATTERN}ClassDom"))
+        class_domain = ClassDomain(FileIO.clean(f"{self._dataset_name}ClassDom"))
+        parent_class_domain = ClassDomain(FileIO.clean(f"{self._dataset_name}{self.PARENT_PATTERN}ClassDom"))
         raw_class_info = {}
         for task in tqdm(self._data_info["tasks"], desc="parsing class domain..."):
             task_type, catalog = task["type"], task["catalog"]
@@ -131,18 +142,21 @@ class DetectionParse:
             if annotations:
                 sample_item["annotations"] = annotations
 
-            sample_container.add_item(sample_item)
+            sample_container.add_item(sample_item, not self.separate_flag)
         return (object_struct, sample_struct), sample_container
 
-    @staticmethod
-    def _read_json(file):
-        with open(file, "r") as f:
-            json_info = json.load(f)
-        return json_info
+    def _read_json(self, file, encoding="utf-8"):
+        bytes_info = self.file_client.get(file)
+        try:
+            text = bytes_info.decode(encoding)
+        except Exception as e:
+            raise RuntimeError(f"Failed to read '{file}'. {e}") from None
 
-    @staticmethod
-    def clean(varStr):
-        return re.sub('\W|^(?=\d)', '', varStr)
+        try:
+            json_info = json.loads(text)
+        except Exception as e:
+            raise RuntimeError(f"Failed to load JSON file '{file}'. {e}") from None
+        return json_info
 
     @property
     def struct_defs(self):
